@@ -1,21 +1,22 @@
-"""
-Radicale management frontend.
-
-"""
+"""Radicale management frontend."""
 
+from django.urls import reverse_lazy
 from django.utils.translation import ugettext_lazy
 
 from modoboa.core.extensions import ModoExtension, exts_pool
-from modoboa.lib import parameters
+from modoboa.parameters import tools as param_tools
+
+from . import __version__
+from . import forms
 
 
 class Radicale(ModoExtension):
-
     """Radicale extension declaration."""
 
     name = "modoboa_radicale"
     label = ugettext_lazy("Radicale management")
-    version = "1.0.4"
+    topredirection_url = reverse_lazy("modoboa_radicale:index")
+    version = __version__
     url = "calendars"
     description = ugettext_lazy(
         "Management frontend for Radicale, a simple calendar and contact "
@@ -24,9 +25,7 @@ class Radicale(ModoExtension):
 
     def load(self):
         """Plugin loading."""
-        from .app_settings import ParametersForm
-
-        parameters.register(ParametersForm, "Radicale")
-        from . import general_callbacks
+        param_tools.registry.add(
+            "global", forms.ParametersForm, "Radicale")
 
 exts_pool.register_extension(Radicale)
